let ctx = null;
const updateCounters = /* @__PURE__ */ new WeakMap();
const elements = /* @__PURE__ */ new Set();
function initCanvas() {
  const canvas = document.createElement("canvas");
  canvas.id = "vue-change-marker-canvas";
  canvas.style.position = "fixed";
  canvas.style.top = "0";
  canvas.style.left = "0";
  canvas.style.width = "100vw";
  canvas.style.height = "100vh";
  canvas.style.pointerEvents = "none";
  canvas.style.zIndex = "2147483646";
  canvas.setAttribute("aria-hidden", "true");
  const canvasCtx = canvas.getContext("2d");
  ctx = canvasCtx;
  document.documentElement.appendChild(canvas);
  const dpi = window.devicePixelRatio || 1;
  canvasCtx.canvas.width = dpi * window.innerWidth;
  canvasCtx.canvas.height = dpi * window.innerHeight;
  canvas.style.width = `${window.innerWidth}px`;
  canvas.style.height = `${window.innerHeight}px`;
  canvasCtx.resetTransform();
  canvasCtx.scale(dpi, dpi);
}
function clearCanvas(ctx2) {
  ctx2.save();
  ctx2.setTransform(1, 0, 0, 1, 0, 0);
  const width = ctx2.canvas.width;
  const height = ctx2.canvas.height;
  ctx2.clearRect(0, 0, width, height);
  ctx2.restore();
}
function resetCounters() {
  elements.forEach((el) => {
    updateCounters.set(el, 0);
  });
}
function highlight(ctx2, el, updatedInstance) {
  clearCanvas(ctx2);
  let updateCounter = updateCounters.get(el) || 0;
  updateCounter++;
  updateCounters.set(el, updateCounter);
  elements.add(el);
  const opacity = Math.min(0.9, updateCounter * 0.2);
  const rect = el.getBoundingClientRect();
  const componentName = updatedInstance.type.__name || updatedInstance.type.__file || "";
  ctx2.save();
  ctx2.fillStyle = `rgba(255, 0, 0, ${opacity})`;
  ctx2.fillRect(rect.x, rect.y - 40, Math.max(250, rect.width), 40);
  ctx2.fillStyle = `white`;
  ctx2.font = "14px Arial";
  ctx2.fillText("updated component: " + componentName, rect.x, rect.y - 25);
  ctx2.fillText("updated times: " + updateCounter, rect.x, rect.y - 5);
  ctx2.restore();
  ctx2.save();
  ctx2.strokeStyle = `rgba(255, 0, 0, ${opacity})`;
  ctx2.lineWidth = 1;
  ctx2.strokeRect(rect.x, rect.y, rect.width, rect.height);
  ctx2.restore();
}
const getRect = (domNode) => {
  const style = window.getComputedStyle(domNode);
  if (style.display === "none" || style.visibility === "hidden" || style.opacity === "0") {
    return null;
  }
  const rect = domNode.getBoundingClientRect();
  const isVisible = rect.bottom > 0 && rect.right > 0 && rect.top < window.innerHeight && rect.left < window.innerWidth;
  if (!isVisible || !rect.width || !rect.height) {
    return null;
  }
  return rect;
};
export {
  clearCanvas,
  ctx,
  getRect,
  highlight,
  initCanvas,
  resetCounters
};
